@@ -24,7 +24,6 @@
 #include "messagecomposer_export.h"
 #include "messagecomposer/messagesender.h"
 #include "MessageComposer/Recipient"
-
 #include <AkonadiCore/collection.h>
 #include <KMime/Message>
 
@@ -170,7 +169,6 @@ public:
     *  values are set before sending.
     */
     void setFrom(const QString &from);
-    void setReplyTo(const QString &replyTo);
     void setSubject(const QString &subject);
 
     /**
@@ -232,6 +230,9 @@ public:
 
     Q_REQUIRED_RESULT KMime::Message::Ptr msg() const;
 
+    bool requestDeleveryConfirmation() const;
+    void setRequestDeleveryConfirmation(bool requestDeleveryConfirmation);
+
 public Q_SLOTS:
     void identityChanged(const KIdentityManagement::Identity &ident, const KIdentityManagement::Identity &oldIdent, bool msgCleared = false);
 
@@ -348,9 +349,12 @@ private:
     bool m_neverEncrypt = false;
     bool m_mdnRequested = false;
     bool m_urgent = false;
+    bool m_requestDeleveryConfirmation = false;
     Kleo::CryptoMessageFormat m_cryptoMessageFormat;
-    QString mExpandedFrom, m_from, m_replyTo, m_subject;
-    QStringList mExpandedTo, mExpandedCc, mExpandedBcc;
+    QString mExpandedFrom;
+    QString m_from;
+    QString m_subject;
+    QStringList mExpandedTo, mExpandedCc, mExpandedBcc, mExpandedReplyTo;
     QList< QByteArray > m_charsets;
     QMap<QByteArray, QString> m_customHeader;
 
