@@ -5,8 +5,9 @@
     Copyright (c) 2003 Marc Mutz <mutz@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License, version 2, as
-    published by the Free Software Foundation.
+    under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
 
     KMail is distributed in the hope that it will be useful, but
     WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -60,10 +61,10 @@ public:
         Display, Hide
     };
 
-    virtual QStringList headersToDisplay() const;
-    virtual QStringList headersToHide() const;
-    virtual DefaultPolicy defaultPolicy() const = 0;
-    virtual bool showHeader(const QString &header) const;
+    Q_REQUIRED_RESULT virtual QStringList headersToDisplay() const;
+    Q_REQUIRED_RESULT virtual QStringList headersToHide() const;
+    Q_REQUIRED_RESULT virtual DefaultPolicy defaultPolicy() const = 0;
+    Q_REQUIRED_RESULT virtual bool showHeader(const QString &header) const;
     static QStringList stringList(const char *const headers[], int numHeaders);
 };
 }
